[m-dev.] trivial diff: update terminology in the decl debugger

Mark Anthony BROWN dougl at cs.mu.OZ.AU
Thu Jun 15 01:38:37 AEST 2000


Estimated hours taken: 0.2

Make the code consistent with the terminology in the DD paper.

browser/declarative_execution.m:
trace/mercury_trace_declarative.c:
	s/step_left_in_context/step_left_in_contour/g

Index: browser/declarative_execution.m
===================================================================
RCS file: /home/mercury1/repository/mercury/browser/declarative_execution.m,v
retrieving revision 1.9
diff -u -r1.9 declarative_execution.m
--- browser/declarative_execution.m	2000/05/08 18:16:23	1.9
+++ browser/declarative_execution.m	2000/06/14 15:31:51
@@ -504,20 +504,20 @@
 trace_node_first_disj(later_disj(_, _, FirstDisj), FirstDisj).	
 
 	% Given any node in an annotated trace, find the most recent
 	% node in the same context which has not been backtracked over,
 	% skipping negations, conditions, the bodies of calls, and
 	% alternative disjuncts.  Return the NULL reference if there
 	% is no such node (eg. if we are at the start of a negation,
 	% condition, or call).
 	%
-:- func step_left_in_context(trace_node_store, trace_node(trace_node_id))
+:- func step_left_in_contour(trace_node_store, trace_node(trace_node_id))
 		= trace_node_id.
-:- pragma export(step_left_in_context(in, in) = out,
-		"MR_DD_step_left_in_context").
+:- pragma export(step_left_in_contour(in, in) = out,
+		"MR_DD_step_left_in_contour").
 
-step_left_in_context(_, call(_, _, _, _, _, _)) = _ :-
-	error("step_left_in_context: unexpected CALL node").
-step_left_in_context(_, cond(Prec, _, Status)) = Node :-
+step_left_in_contour(_, call(_, _, _, _, _, _)) = _ :-
+	error("step_left_in_contour: unexpected CALL node").
+step_left_in_contour(_, cond(Prec, _, Status)) = Node :-
 	(
 		Status = succeeded
 	->
@@ -525,24 +525,24 @@
 	;
 		null_trace_node_id(Node)
 	).
-step_left_in_context(_, neg(_, _, _)) = _ :-
-	error("step_left_in_context: unexpected NEGE node").
-step_left_in_context(Store, exit(_, Call, _, _, _)) = Prec :-
+step_left_in_contour(_, neg(_, _, _)) = _ :-
+	error("step_left_in_contour: unexpected NEGE node").
+step_left_in_contour(Store, exit(_, Call, _, _, _)) = Prec :-
 	call_node_from_id(Store, Call, call(Prec, _, _, _, _, _)).
-step_left_in_context(Store, fail(_, Call, _, _)) = Prec :-
+step_left_in_contour(Store, fail(_, Call, _, _)) = Prec :-
 	call_node_from_id(Store, Call, call(Prec, _, _, _, _, _)).
-step_left_in_context(_, redo(_, _)) = _ :-
-	error("step_left_in_context: unexpected REDO node").
-step_left_in_context(_, switch(Prec, _)) = Prec.
-step_left_in_context(_, first_disj(Prec, _)) = Prec.
-step_left_in_context(Store, later_disj(_, _, FirstDisj)) = Prec :-
+step_left_in_contour(_, redo(_, _)) = _ :-
+	error("step_left_in_contour: unexpected REDO node").
+step_left_in_contour(_, switch(Prec, _)) = Prec.
+step_left_in_contour(_, first_disj(Prec, _)) = Prec.
+step_left_in_contour(Store, later_disj(_, _, FirstDisj)) = Prec :-
 	first_disj_node_from_id(Store, FirstDisj, first_disj(Prec, _)).
-step_left_in_context(_, then(Prec, _)) = Prec.
-step_left_in_context(Store, else(_, Cond)) = Prec :-
+step_left_in_contour(_, then(Prec, _)) = Prec.
+step_left_in_contour(Store, else(_, Cond)) = Prec :-
 	cond_node_from_id(Store, Cond, cond(Prec, _, _)).
-step_left_in_context(Store, neg_succ(_, Neg)) = Prec :-
+step_left_in_contour(Store, neg_succ(_, Neg)) = Prec :-
 	neg_node_from_id(Store, Neg, neg(Prec, _, _)).
-step_left_in_context(Store, neg_fail(_, Neg)) = Prec :-
+step_left_in_contour(Store, neg_fail(_, Neg)) = Prec :-
 	neg_node_from_id(Store, Neg, neg(Prec, _, _)).
 
 	% Given any node in an annotated trace, find a node in
@@ -504,20 +504,20 @@
 
 	% Given any node in an annotated trace, find the most recent
-	% node in the same context which has not been backtracked over,
-	% skipping negations, conditions, the bodies of calls, and
-	% alternative disjuncts.  Return the NULL reference if there
-	% is no such node (eg. if we are at the start of a negation,
-	% condition, or call).
+	% node in the same contour (ie. the last node which has not been
+	% backtracked over, skipping negations, conditions, the bodies
+	% of calls, and alternative disjuncts).  Return the NULL reference
+	% if there is no such node (eg. if we are at the start of a
+	% negation, condition, or call).
 	%
Index: trace/mercury_trace_declarative.c
===================================================================
RCS file: /home/mercury1/repository/mercury/trace/mercury_trace_declarative.c,v
retrieving revision 1.22
diff -u -r1.22 mercury_trace_declarative.c
--- trace/mercury_trace_declarative.c	2000/05/15 16:37:41	1.22
+++ trace/mercury_trace_declarative.c	2000/06/14 15:19:53
@@ -261,7 +261,7 @@
 MR_trace_node_first_disj(MR_Trace_Node node);
 
 static	MR_Trace_Node
-MR_trace_step_left_in_context(MR_Trace_Node node);
+MR_trace_step_left_in_contour(MR_Trace_Node node);
 
 static	MR_Trace_Node
 MR_trace_find_prev_contour(MR_Trace_Node node);
@@ -517,7 +517,7 @@
 	while (MR_trace_node_port(next) != MR_PORT_EXIT
 		|| MR_trace_node_seqno(next) != event_info->MR_call_seqno)
 	{
-		next = MR_trace_step_left_in_context(next);
+		next = MR_trace_step_left_in_contour(next);
 	}
 	MR_decl_checkpoint_match(next);
 
@@ -608,7 +608,7 @@
 	next = prev;
 	while (!MR_trace_matching_cond(path, next))
 	{
-		next = MR_trace_step_left_in_context(next);
+		next = MR_trace_step_left_in_contour(next);
 	}
 	cond = next;
 	MR_decl_checkpoint_match(cond);
@@ -644,7 +644,7 @@
 		next = prev;
 		while (!MR_trace_matching_cond(path, next))
 		{
-			next = MR_trace_step_left_in_context(next);
+			next = MR_trace_step_left_in_contour(next);
 		}
 		cond = next;
 	}
@@ -694,7 +694,7 @@
 		next = prev;
 		while (!MR_trace_matching_neg(path, next))
 		{
-			next = MR_trace_step_left_in_context(next);
+			next = MR_trace_step_left_in_contour(next);
 		}
 		nege = next;
 	}
@@ -717,12 +717,12 @@
 	MR_Trace_Node		next;
 
 	/*
 	** Search through current context for a matching NEGE event.
 	*/
 	next = prev;
 	while (!MR_trace_matching_neg(event_info->MR_event_path, next))
 	{
-		next = MR_trace_step_left_in_context(next);
+		next = MR_trace_step_left_in_contour(next);
 	}
 	MR_decl_checkpoint_match(next);
 	
@@ -774,7 +774,7 @@
 		next = MR_trace_find_prev_contour(prev);
 		while (!MR_trace_matching_disj(path, next))
 		{
-			next = MR_trace_step_left_in_context(next);
+			next = MR_trace_step_left_in_contour(next);
 		}
 		MR_decl_checkpoint_match(next);
 
@@ -857,7 +857,7 @@
 	next = node;
 	while (MR_trace_node_port(next) != MR_PORT_CALL)
 	{
-		next = MR_trace_step_left_in_context(next);
+		next = MR_trace_step_left_in_contour(next);
 	}
 	return next;
 }
@@ -1375,7 +1375,7 @@
 }
 
 static	MR_Trace_Node
-MR_trace_step_left_in_context(MR_Trace_Node node)
+MR_trace_step_left_in_contour(MR_Trace_Node node)
 {
 	MR_Trace_Node		next;
 
@@ -1383,7 +1383,7 @@
 
 	MR_trace_node_store++;
 	MR_TRACE_CALL_MERCURY(
-		next = (MR_Trace_Node) MR_DD_step_left_in_context(
+		next = (MR_Trace_Node) MR_DD_step_left_in_contour(
 						MR_trace_node_store, node);
 	);
 	return next;
--------------------------------------------------------------------------
mercury-developers mailing list
Post messages to:       mercury-developers at cs.mu.oz.au
Administrative Queries: owner-mercury-developers at cs.mu.oz.au
Subscriptions:          mercury-developers-request at cs.mu.oz.au
--------------------------------------------------------------------------
@@ -717,12 +717,12 @@
 
 	/*
-	** Search through current context for a matching NEGE event.
+	** Search through current contour for a matching NEGE event.
 	*/
 	next = prev;



More information about the developers mailing list